@@ -6,7 +6,7 @@ use Kavorka -all;
 use utf8;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # V[m] | CH | {CH}C[v][m] | D | F | Hpv | W | Sid | N | Other | NT
 
@@ -20,7 +20,6 @@ our $VERSION = '0.04';
 # H   - Virama
 # D   - Digit
 # F   - fraction
-# Hpv - Historic phonetic variants
 # W   - Weights
 # Sid - Siddham
 # N   - Never occurs, if script is written properly it never matches
@@ -40,7 +39,7 @@ method TE::String::X() {
 }
 
 method TE::Tgc::X() {
-  ($self->{S} || $self->{Vm} || $self->{CH} || $self->{CHCvm} || $self->{D} || $self->{F} || $self->{Hpv} || $self->{W} ||  $self->{Sid} || $self->{N} || $self->{Other} || $self->{NT})->X() ;
+  ($self->{S} || $self->{Vm} || $self->{CH} || $self->{CHCvm} || $self->{D} || $self->{F} || $self->{W} ||  $self->{Sid} || $self->{N} || $self->{Other} || $self->{NT})->X() ;
 }
 
 method TE::S::X() {
@@ -67,10 +66,6 @@ method TE::F::X() {
   push @result, $self->{''};
 }
 
-method TE::Hpv::X() {
-  push @result, $self->{''};
-}
-
 method TE::W::X() {
   push @result, $self->{''};
 }
@@ -96,18 +91,17 @@ my $parser = qr {
     <nocontext:>
     <String>
     <objrule:  TE::String>        <[Tgc]>+
-    <objrule:  TE::Tgc>           <ws: (\s++)*> <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <Hpv> | <W> | <Sid> | <N> | <Other> | <NT>
+    <objrule:  TE::Tgc>           <ws: (\s++)*> <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <W> | <Sid> | <N> | <Other> | <NT>
     <objrule:  TE::Vm>            <V><m_>
     <objrule:  TE::CHCvm>         <CH__><C><v_><m_>
-    <objtoken: TE::CH>            ([క-హ])( ్\b )
+    <objtoken: TE::CH>            ([క-హ ౘ-ౚ])( ్\b )
     <objtoken: TE::V>             [అ-ఔ ౠ-ౡ]
     <objtoken: TE::m_>            [ఀ-ఄ ఽ ౕ ౖ]?
-    <objtoken: TE::CH__>          (([క-హ])(్))*
-    <objtoken: TE::C>             [క-హ]
+    <objtoken: TE::CH__>          (([క-హ ౘ-ౚ])(్))*
+    <objtoken: TE::C>             [క-హ ౘ-ౚ]
     <objtoken: TE::v_>            [ా-ౌ ౢ ౣ]?
     <objtoken: TE::D>             [౦-౯]
     <objtoken: TE::F>             [౸-౾]
-    <objtoken: TE::Hpv>           [ౘ-ౚ]
     <objtoken: TE::W>             [౿]
     <objtoken: TE::Sid>           [౷]
     <objtoken: TE::N>             [ా-ౌ ౢ ౣ ఀ-ఄ ఽ ౕ ౖ]
